ActionSliderController class
- Inheritance
-
- Object
- ChangeNotifier
- ActionSliderController
- Implemented types
Constructors
- ActionSliderController({double anchorPosition = 0.0, SliderInterval allowedInterval = const SliderInterval()})
- ActionSliderController.dual({double anchorPosition = 0.5, SliderInterval allowedInterval = const SliderInterval()})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → ActionSliderControllerState
-
The current value of the object.
no setteroverride
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
custom(
SliderMode mode) → void -
Allows to define custom SliderModes.
This is useful for other results like success or failure.
You get this modes in the
foregroundBuilderofConfirmationSlider.customor in thecustomForegroundBuilderofConfirmationSlider.standard. -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
failure(
) → void - Sets the state to failure
-
jump(
[double dif = 0.3]) → void -
The Toggle jumps to
anchorPosition + dif.difshould be between -1.0 and 1.0. -
loading(
) → void - Sets the state to loading
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
reset(
) → void - Resets the slider to its expanded state
-
setAllowedInterval(
SliderInterval interval) → void -
setAnchorPosition(
double pos) → void -
setAnchorPositionAndAllowedInterval(
{double? anchorPosition, SliderInterval? allowedInterval}) → void -
success(
) → void - Sets the state to success
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited